@@ -1,14 +1,19 @@
 from typing import Dict, List, Optional, Any
 from typing import Callable, Mapping
+from typing import Optional
 # nltk package for preprocessing
 import nltk
 
+from datalabs.operations.tokenizer import get_tokenizer
 from .preprocessing import *
 
 
 @preprocessing(name="lower", contributor="datalab",
                task="Any", description="this function is used to lowercase a given text")
-def lower(text: str) -> str:
+def lower(text: str,
+          task_type: Optional[str] = None,
+          language: Optional[str] = None,
+          ) -> str:
     """
     Package: python
     Input:
@@ -22,7 +27,10 @@ def lower(text: str) -> str:
 
 @preprocessing(name="tokenize_nltk", contributor="nltk",
                task="Any", description="this function is used to tokenize a text using NLTK")
-def tokenize_nltk(text: str) -> List:
+def tokenize_nltk(text: str,
+                  task_type: Optional[str] = None,
+                  language: Optional[str] = None,
+                  ) -> List:
     """
     Package: nltk.word_tokenize
     Input:
@@ -36,7 +44,10 @@ def tokenize_nltk(text: str) -> List:
 
 @preprocessing(name="tokenize_huggingface", contributor="huggingface",
                task="Any", description="this function is used to tokenize a text using huggingface library")
-def tokenize_huggingface(text: str) -> List:
+def tokenize_huggingface(text: str,
+                         task_type: Optional[str] = None,
+                         language: Optional[str] = None,
+                         ) -> List:
     """
     Package: huggingface:tokenizer
     Input:
@@ -56,7 +67,10 @@ def tokenize_huggingface(text: str) -> List:
 
 @preprocessing(name="stem", contributor="nltk",
                task="Any", description="this function is used to stem a text using NLTK")
-def stem(text: str) -> List:
+def stem(text: str,
+         task_type:Optional[str] = None,
+         language:Optional[str] = None,
+         ) -> List:
     """
     Package: nltk.stem
     Input:
@@ -69,3 +83,15 @@ def stem(text: str) -> List:
     # text = sample['text']
     stem_words = [porter.stem(word) for word in text.split(" ")]
     return {"text_stem": stem_words}
+
+
+
+@preprocessing(name="tokenize", contributor="datalabs",
+               task="Any", description="this function is used to tokenize a text")
+def tokenize(text:str,
+             tokenizer_name:Optional[str] = None,
+             task_type:str = None,
+             language:str = None) -> List[str]:
+
+    tokenizer = get_tokenizer(tokenizer_name, task_type, language)
+    return {"text_tokenized": " ".join(tokenizer(text))}
